package com.temboo.Library.Zoho.CRM;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import processing.data.JSONArray;
import processing.data.JSONObject;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetRecords

Retrieves all users data specified in the API request.
*/
public class GetRecords extends Choreography {

	/**
	Create a new instance of the GetRecords Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetRecords(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Zoho/CRM/GetRecords"));
	}

	/** 
	Set the value of the AuthenticationToken input for this Choreo. 

	@param String - (required, string) A valid authentication token. Permanent authentication tokens can be generated by the GenerateAuthToken Choreo.
	*/
	public void setAuthenticationToken(String value) {
		this.inputs.setInput("AuthenticationToken", value);
	}


	/** 
	Set the value of the FromIndex input for this Choreo. 

	@param Integer - (optional, integer) The beginning index of the result set to return. Defaults to 1.
	*/
	public void setFromIndex(Integer value) {
		this.inputs.setInput("FromIndex", value);
	}

	/** 
	Set the value of the FromIndex input for this Choreo as a String. 

	@param String - (optional, integer) The beginning index of the result set to return. Defaults to 1.
	*/
	public void setFromIndex(String value) {
		this.inputs.setInput("FromIndex", value);	
	}
	/** 
	Set the value of the LastModifiedTime input for this Choreo. 

	@param String - (optional, date) Used to return records with a created or modified date that is after the specified time.  (i.e. 2010-04-21 11:09:23)
	*/
	public void setLastModifiedTime(String value) {
		this.inputs.setInput("LastModifiedTime", value);
	}


	/** 
	Set the value of the Module input for this Choreo. 

	@param String - (optional, string) The Zoho module you want to access. Defaults to 'Leads'.
	*/
	public void setModule(String value) {
		this.inputs.setInput("Module", value);
	}


	/** 
	Set the value of the ResponseFormat input for this Choreo. 

	@param String - (optional, string) The format that the response should be in. Valid formats are: json and xml (the default).
	*/
	public void setResponseFormat(String value) {
		this.inputs.setInput("ResponseFormat", value);
	}


	/** 
	Set the value of the SelectColumns input for this Choreo. 

	@param String - (optional, string) The columns to return separated by commas (i.e. First Name,Last Name,Email). When left empty, only IDs are returned.
	*/
	public void setSelectColumns(String value) {
		this.inputs.setInput("SelectColumns", value);
	}


	/** 
	Set the value of the SortColumnString input for this Choreo. 

	@param String - (optional, string) Used to specify a column to sort by (in ascending order)
	*/
	public void setSortColumnString(String value) {
		this.inputs.setInput("SortColumnString", value);
	}


	/** 
	Set the value of the SortOrderString input for this Choreo. 

	@param String - (optional, string) Sorting order: asc or desc. Default sort order is set to ascending.
	*/
	public void setSortOrderString(String value) {
		this.inputs.setInput("SortOrderString", value);
	}


	/** 
	Set the value of the ToIndex input for this Choreo. 

	@param Integer - (optional, integer) The ending index of the result set to return. Defaults to 20. Max is 200.
	*/
	public void setToIndex(Integer value) {
		this.inputs.setInput("ToIndex", value);
	}

	/** 
	Set the value of the ToIndex input for this Choreo as a String. 

	@param String - (optional, integer) The ending index of the result set to return. Defaults to 20. Max is 200.
	*/
	public void setToIndex(String value) {
		this.inputs.setInput("ToIndex", value);	
	}
	
	/**
	 * Execute the Choreo, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 */
	@Override
	public GetRecordsResultSet run() {
		JSONObject result = super.runWithResults();
		return new GetRecordsResultSet(result);
	}
	
}
